# Introduction

Get your risk metrics **alpha, beta** out of box.

## Installation
```
pip install finstats
```

# Usage
```bash
finstats -s sh600519 -b sh000001
```

# Data Source

Finstats uses Sina HTTP API as its data source